@@ -3,7 +3,7 @@
  * @ingroup MAT
  */
 /*
- * Copyright (c) 2015-2022, The matio contributors
+ * Copyright (c) 2015-2024, The matio contributors
  * Copyright (c) 2005-2014, Christopher C. Hulbert
  * All rights reserved.
  *
@@ -122,58 +122,58 @@
     } while ( 0 )
 
 #if HAVE_ZLIB
-#define READ_COMPRESSED_DATA_NOSWAP(T)                         \
-    do {                                                       \
-        const size_t block_size = READ_BLOCK_SIZE / data_size; \
-        if ( len <= block_size ) {                             \
-            InflateData(mat, z, v, len *data_size);            \
-            for ( i = 0; i < len; i++ ) {                      \
-                data[i] = (T)v[i];                             \
-            }                                                  \
-        } else {                                               \
-            mat_uint32_t j;                                    \
-            len -= block_size;                                 \
-            for ( i = 0; i < len; i += block_size ) {          \
-                InflateData(mat, z, v, block_size *data_size); \
-                for ( j = 0; j < block_size; j++ ) {           \
-                    data[i + j] = (T)v[j];                     \
-                }                                              \
-            }                                                  \
-            len -= (i - block_size);                           \
-            InflateData(mat, z, v, len *data_size);            \
-            for ( j = 0; j < len; j++ ) {                      \
-                data[i + j] = (T)v[j];                         \
-            }                                                  \
-        }                                                      \
+#define READ_COMPRESSED_DATA_NOSWAP(T)                                          \
+    do {                                                                        \
+        const size_t block_size = READ_BLOCK_SIZE / data_size;                  \
+        if ( len <= block_size ) {                                              \
+            InflateData(mat, z, v, (mat_uint32_t)(len * data_size));            \
+            for ( i = 0; i < len; i++ ) {                                       \
+                data[i] = (T)v[i];                                              \
+            }                                                                   \
+        } else {                                                                \
+            mat_uint32_t j;                                                     \
+            len -= (mat_uint32_t)block_size;                                    \
+            for ( i = 0; i < len; i += (mat_uint32_t)block_size ) {             \
+                InflateData(mat, z, v, (mat_uint32_t)(block_size * data_size)); \
+                for ( j = 0; j < block_size; j++ ) {                            \
+                    data[i + j] = (T)v[j];                                      \
+                }                                                               \
+            }                                                                   \
+            len -= (mat_uint32_t)(i - block_size);                              \
+            InflateData(mat, z, v, (mat_uint32_t)(len * data_size));            \
+            for ( j = 0; j < len; j++ ) {                                       \
+                data[i + j] = (T)v[j];                                          \
+            }                                                                   \
+        }                                                                       \
     } while ( 0 )
 
-#define READ_COMPRESSED_DATA(T, SwapFunc)                          \
-    do {                                                           \
-        if ( mat->byteswap ) {                                     \
-            const size_t block_size = READ_BLOCK_SIZE / data_size; \
-            if ( len <= block_size ) {                             \
-                InflateData(mat, z, v, len *data_size);            \
-                for ( i = 0; i < len; i++ ) {                      \
-                    data[i] = (T)SwapFunc(&v[i]);                  \
-                }                                                  \
-            } else {                                               \
-                mat_uint32_t j;                                    \
-                len -= block_size;                                 \
-                for ( i = 0; i < len; i += block_size ) {          \
-                    InflateData(mat, z, v, block_size *data_size); \
-                    for ( j = 0; j < block_size; j++ ) {           \
-                        data[i + j] = (T)SwapFunc(&v[j]);          \
-                    }                                              \
-                }                                                  \
-                len -= (i - block_size);                           \
-                InflateData(mat, z, v, len *data_size);            \
-                for ( j = 0; j < len; j++ ) {                      \
-                    data[i + j] = (T)SwapFunc(&v[j]);              \
-                }                                                  \
-            }                                                      \
-        } else {                                                   \
-            READ_COMPRESSED_DATA_NOSWAP(T);                        \
-        }                                                          \
+#define READ_COMPRESSED_DATA(T, SwapFunc)                                           \
+    do {                                                                            \
+        if ( mat->byteswap ) {                                                      \
+            const size_t block_size = READ_BLOCK_SIZE / data_size;                  \
+            if ( len <= block_size ) {                                              \
+                InflateData(mat, z, v, (mat_uint32_t)(len * data_size));            \
+                for ( i = 0; i < len; i++ ) {                                       \
+                    data[i] = (T)SwapFunc(&v[i]);                                   \
+                }                                                                   \
+            } else {                                                                \
+                mat_uint32_t j;                                                     \
+                len -= (mat_uint32_t)block_size;                                    \
+                for ( i = 0; i < len; i += (mat_uint32_t)block_size ) {             \
+                    InflateData(mat, z, v, (mat_uint32_t)(block_size * data_size)); \
+                    for ( j = 0; j < block_size; j++ ) {                            \
+                        data[i + j] = (T)SwapFunc(&v[j]);                           \
+                    }                                                               \
+                }                                                                   \
+                len -= (mat_uint32_t)(i - block_size);                              \
+                InflateData(mat, z, v, (mat_uint32_t)(len * data_size));            \
+                for ( j = 0; j < len; j++ ) {                                       \
+                    data[i + j] = (T)SwapFunc(&v[j]);                               \
+                }                                                                   \
+            }                                                                       \
+        } else {                                                                    \
+            READ_COMPRESSED_DATA_NOSWAP(T);                                         \
+        }                                                                           \
     } while ( 0 )
 
 #endif
@@ -496,7 +496,7 @@ ReadCharData(mat_t *mat, void *_data, enum matio_types data_type, size_t len)
  */
 int
 ReadDataSlabN(mat_t *mat, void *data, enum matio_classes class_type, enum matio_types data_type,
-              int rank, size_t *dims, int *start, int *stride, int *edge)
+              int rank, const size_t *dims, const int *start, const int *stride, const int *edge)
 {
     int nBytes = 0, i, j, N, I = 0;
     int inc[10] =
@@ -676,8 +676,8 @@ ReadDataSlabN(mat_t *mat, void *data, enum matio_classes class_type, enum matio_
  */
 int
 ReadCompressedDataSlabN(mat_t *mat, z_streamp z, void *data, enum matio_classes class_type,
-                        enum matio_types data_type, int rank, size_t *dims, int *start, int *stride,
-                        int *edge)
+                        enum matio_types data_type, int rank, const size_t *dims, const int *start,
+                        const int *stride, const int *edge)
 {
     int nBytes = 0, i, j, N, I = 0, err;
     int inc[10] =
@@ -927,7 +927,7 @@ ReadDataSlab1(mat_t *mat, void *data, enum matio_classes class_type, enum matio_
  */
 int
 ReadDataSlab2(mat_t *mat, void *data, enum matio_classes class_type, enum matio_types data_type,
-              size_t *dims, int *start, int *stride, int *edge)
+              const size_t *dims, const int *start, const int *stride, const int *edge)
 {
     int nBytes = 0, data_size, i, j;
     long pos, row_stride, col_stride, pos2;
@@ -1162,8 +1162,8 @@ ReadCompressedDataSlab1(mat_t *mat, z_streamp z, void *data, enum matio_classes
  */
 int
 ReadCompressedDataSlab2(mat_t *mat, z_streamp z, void *data, enum matio_classes class_type,
-                        enum matio_types data_type, size_t *dims, int *start, int *stride,
-                        int *edge)
+                        enum matio_types data_type, const size_t *dims, const int *start,
+                        const int *stride, const int *edge)
 {
     int nBytes = 0, i, j, err;
     int pos, row_stride, col_stride;
