@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2023, The matio contributors
+ * Copyright (c) 2015-2024, The matio contributors
  * Copyright (c) 2005-2014, Christopher C. Hulbert
  * All rights reserved.
  *
@@ -25,6 +25,7 @@
  * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include "matioConfig.h"
 #include "matio.h"
 #include <getopt.h>
 #include <stdlib.h>
@@ -38,14 +39,20 @@
 #define SIZE_T_FMTSTR "zu"
 #endif
 
-static const char *optstring = "df:hvHV";
-static struct option options[] = {{"data", no_argument, NULL, 'd'},
-                                  {"format", required_argument, NULL, 'f'},
-                                  {"human", no_argument, NULL, 'h'},
-                                  {"verbose", optional_argument, NULL, 'v'},
-                                  {"help", no_argument, NULL, 'H'},
-                                  {"version", no_argument, NULL, 'V'},
-                                  {NULL, 0, NULL, 0}};
+/* snprintf.c */
+#if !HAVE_SNPRINTF
+int rpl_snprintf(char *, size_t, const char *, ...);
+#define mat_snprintf rpl_snprintf
+#else
+#define mat_snprintf snprintf
+#endif /* !HAVE_SNPRINTF */
+
+static const char *optstring = "df:hvo:HV";
+static struct option options[] = {
+    {"data", no_argument, NULL, 'd'},         {"format", required_argument, NULL, 'f'},
+    {"human", no_argument, NULL, 'h'},        {"verbose", optional_argument, NULL, 'v'},
+    {"help", no_argument, NULL, 'H'},         {"version", no_argument, NULL, 'V'},
+    {"output", required_argument, NULL, 'o'}, {NULL, 0, NULL, 0}};
 
 static const char *helpstr[] = {"",
                                 "Usage: matdump [OPTIONS] mat_file [var1 var2 ...]",
@@ -76,10 +83,10 @@ static int human_readable = 0;
 static int print_whos_first = 1;
 
 /* Print Functions */
-static void print_whos(matvar_t *matvar);
-static void print_default(matvar_t *matvar);
+static void print_whos(const matvar_t *matvar);
+static void print_default(const matvar_t *matvar);
 
-static void (*printfunc)(matvar_t *matvar) = NULL;
+static void (*printfunc)(const matvar_t *matvar) = NULL;
 
 static char *
 get_next_token(char *str)
@@ -104,7 +111,7 @@ get_next_token(char *str)
 }
 
 static int
-slab_get_rank(char *open, char *close)
+slab_get_rank(char *open, const char *close)
 {
     int rank = 0;
     char *ptr = open + 1;
@@ -117,15 +124,12 @@ slab_get_rank(char *open, char *close)
 }
 
 static void
-slab_get_select(char *open, char *close, int rank, int *start, int *stride, int *edge)
+slab_get_select(char *open, const char *close, int rank, int *start, int *stride, int *edge)
 {
-    char *ptr, *valptr;
-    int nvals, dim, i;
-
-    ptr = open;
-    valptr = open + 1;
-    dim = 0;
-    nvals = 0;
+    char *ptr = open;
+    const char *valptr = open + 1;
+    int dim = 0;
+    int nvals = 0;
     do {
         ptr++;
         if ( *ptr == ',' ) {
@@ -134,16 +138,14 @@ slab_get_select(char *open, char *close, int rank, int *start, int *stride, int
                 if ( !strcmp(valptr, "end") ) {
                     edge[dim] = -1;
                 } else {
-                    i = (int)strtol(valptr, NULL, 10);
-                    edge[dim] = i;
+                    edge[dim] = (int)strtol(valptr, NULL, 10);
                 }
             } else if ( nvals == 1 ) {
                 *ptr = '\0';
                 if ( !strcmp(valptr, "end") ) {
                     edge[dim] = -1;
                 } else {
-                    i = (int)strtol(valptr, NULL, 10);
-                    edge[dim] = i;
+                    edge[dim] = (int)strtol(valptr, NULL, 10);
                 }
             } else if ( nvals == 0 ) {
                 *ptr = '\0';
@@ -151,7 +153,7 @@ slab_get_select(char *open, char *close, int rank, int *start, int *stride, int
                     start[dim] = -1;
                     edge[dim] = -1;
                 } else {
-                    i = (int)strtol(valptr, NULL, 10);
+                    int i = (int)strtol(valptr, NULL, 10);
                     start[dim] = i - 1;
                     edge[dim] = i;
                 }
@@ -171,7 +173,7 @@ slab_get_select(char *open, char *close, int rank, int *start, int *stride, int
                 else
                     fprintf(stderr, "Too many inputs to dim %d", dim + 1);
             } else {
-                i = (int)strtol(valptr, NULL, 10);
+                int i = (int)strtol(valptr, NULL, 10);
                 if ( nvals == 0 )
                     start[dim] = i - 1;
                 else if ( nvals == 1 )
@@ -196,7 +198,7 @@ slab_get_select(char *open, char *close, int rank, int *start, int *stride, int
                 else
                     fprintf(stderr, "Too many inputs to dim %d", dim + 1);
             } else {
-                i = (int)strtol(valptr, NULL, 10);
+                int i = (int)strtol(valptr, NULL, 10);
                 if ( nvals == 0 ) {
                     start[dim] = i - 1;
                     edge[dim] = i;
@@ -308,7 +310,7 @@ read_selected_data(mat_t *mat, matvar_t **_matvar, char *index_str)
 {
     char *next_tok_pos, next_tok = 0;
     char *open = NULL, *close = NULL;
-    int err = 1, i = 0, j, done = 0;
+    int err = 1, j, done = 0;
     matvar_t *matvar = *_matvar;
 
     next_tok_pos = get_next_token(index_str);
@@ -376,6 +378,7 @@ read_selected_data(mat_t *mat, matvar_t **_matvar, char *index_str)
                         matvar->dims[1] = 1;
                     }
                 } else {
+                    int i;
                     err = Mat_VarReadData(mat, matvar, matvar->data, start, stride, edge);
                     for ( i = 0; i < rank; i++ )
                         matvar->dims[i] = (size_t)edge[i];
@@ -386,9 +389,7 @@ read_selected_data(mat_t *mat, matvar_t **_matvar, char *index_str)
             free(edge);
         } else if ( next_tok == '.' ) {
             matvar_t *field;
-            char *varname;
-
-            varname = next_tok_pos + 1;
+            const char *varname = next_tok_pos + 1;
             if ( matvar->class_type == MAT_C_STRUCT ) {
                 next_tok_pos = get_next_token(next_tok_pos + 1);
                 if ( next_tok_pos != varname ) {
@@ -412,7 +413,7 @@ read_selected_data(mat_t *mat, matvar_t **_matvar, char *index_str)
                 }
             } else if ( matvar->class_type == MAT_C_CELL ) {
                 int ncells;
-                matvar_t *cell, **cells;
+                matvar_t **cells;
 
                 ncells = matvar->nbytes / matvar->data_size;
                 cells = (matvar_t **)matvar->data;
@@ -424,7 +425,7 @@ read_selected_data(mat_t *mat, matvar_t **_matvar, char *index_str)
                     done = 1;
                 }
                 for ( j = 0; j < ncells; j++ ) {
-                    cell = Mat_VarGetCell(matvar, j);
+                    matvar_t *cell = Mat_VarGetCell(matvar, j);
                     if ( cell == NULL || cell->class_type != MAT_C_STRUCT ) {
                         fprintf(stderr, "cell index %d is not a structure", j);
                         break;
@@ -491,6 +492,7 @@ read_selected_data(mat_t *mat, matvar_t **_matvar, char *index_str)
                         matvar->dims[0] = *edge;
                     }
                 } else {
+                    int i;
                     cells = Mat_VarGetCells(matvar, start, stride, edge);
                     for ( i = 0; i < rank; i++ )
                         matvar->dims[i] = (size_t)edge[i];
@@ -521,13 +523,9 @@ read_selected_data(mat_t *mat, matvar_t **_matvar, char *index_str)
 }
 
 static void
-print_whos(matvar_t *matvar)
+print_whos(const matvar_t *matvar)
 {
-    int i;
     size_t nbytes;
-    char size[32] = {
-        '\0',
-    };
 
     if ( print_whos_first ) {
         printf("%-20s       %-10s     %-10s     %-18s\n\n", "Name", "Size", "Bytes", "Class");
@@ -535,11 +533,19 @@ print_whos(matvar_t *matvar)
     }
     printf("%-20s", matvar->name);
     if ( matvar->rank > 0 ) {
-        int cnt = 0;
+        int cnt = 0, i;
+        char size[32] = {
+            '\0',
+        };
         printf("%8" SIZE_T_FMTSTR, matvar->dims[0]);
         for ( i = 1; i < matvar->rank; i++ ) {
-            if ( ceil(log10((double)matvar->dims[i])) + 1 < 32 )
-                cnt += sprintf(size + cnt, "x%" SIZE_T_FMTSTR, matvar->dims[i]);
+            if ( ceil(log10((double)matvar->dims[i])) + 1 < 32 ) {
+                cnt += mat_snprintf(size + cnt, sizeof(size) - cnt, "x%" SIZE_T_FMTSTR,
+                                    matvar->dims[i]);
+                if ( cnt >= sizeof(size) ) {
+                    break;
+                }
+            }
         }
         printf("%-10s", size);
     } else {
@@ -564,7 +570,7 @@ print_whos(matvar_t *matvar)
 static size_t indent = 0;
 
 static void
-default_printf_func(int log_level, char *message)
+default_printf_func(int log_level, const char *message)
 {
     size_t i;
 
@@ -574,7 +580,7 @@ default_printf_func(int log_level, char *message)
 }
 
 static void
-print_default_number(enum matio_types type, void *data)
+print_default_number(enum matio_types type, const void *data)
 {
     switch ( type ) {
         case MAT_T_DOUBLE:
@@ -629,7 +635,7 @@ print_default_number(enum matio_types type, void *data)
 }
 
 static void
-print_default_numeric_2d(matvar_t *matvar)
+print_default_numeric_2d(const matvar_t *matvar)
 {
     size_t i, j, stride;
 
@@ -638,9 +644,9 @@ print_default_numeric_2d(matvar_t *matvar)
 
     stride = Mat_SizeOf(matvar->data_type);
     if ( matvar->isComplex ) {
-        mat_complex_split_t *complex_data = (mat_complex_split_t *)matvar->data;
-        char *rp = (char *)complex_data->Re;
-        char *ip = (char *)complex_data->Im;
+        const mat_complex_split_t *complex_data = (mat_complex_split_t *)matvar->data;
+        const char *rp = (char *)complex_data->Re;
+        const char *ip = (char *)complex_data->Im;
         for ( i = 0; i < matvar->dims[0]; i++ ) {
             for ( j = 0; j < matvar->dims[1]; j++ ) {
                 size_t idx = matvar->dims[0] * j + i;
@@ -652,7 +658,7 @@ print_default_numeric_2d(matvar_t *matvar)
             printf("\n");
         }
     } else {
-        char *data = (char *)matvar->data;
+        const char *data = (char *)matvar->data;
         for ( i = 0; i < matvar->dims[0]; i++ ) {
             for ( j = 0; j < matvar->dims[1]; j++ ) {
                 size_t idx = matvar->dims[0] * j + i;
@@ -665,7 +671,7 @@ print_default_numeric_2d(matvar_t *matvar)
 }
 
 static void
-print_default_numeric_3d(matvar_t *matvar)
+print_default_numeric_3d(const matvar_t *matvar)
 {
     size_t i, j, k, l, stride;
 
@@ -674,9 +680,9 @@ print_default_numeric_3d(matvar_t *matvar)
 
     stride = Mat_SizeOf(matvar->data_type);
     if ( matvar->isComplex ) {
-        mat_complex_split_t *complex_data = (mat_complex_split_t *)matvar->data;
-        char *rp = (char *)complex_data->Re;
-        char *ip = (char *)complex_data->Im;
+        const mat_complex_split_t *complex_data = (mat_complex_split_t *)matvar->data;
+        const char *rp = (char *)complex_data->Re;
+        const char *ip = (char *)complex_data->Im;
         for ( k = 0; k < matvar->dims[2]; k++ ) {
             Mat_Message("%s(:,:,%zu) = ", matvar->name, k);
             indent++;
@@ -696,7 +702,7 @@ print_default_numeric_3d(matvar_t *matvar)
             printf("\n");
         }
     } else {
-        char *data = (char *)matvar->data;
+        const char *data = (char *)matvar->data;
         for ( k = 0; k < matvar->dims[2]; k++ ) {
             Mat_Message("%s(:,:,%zu) = ", matvar->name, k);
             indent++;
@@ -717,7 +723,7 @@ print_default_numeric_3d(matvar_t *matvar)
 }
 
 static void
-print_default(matvar_t *matvar)
+print_default(const matvar_t *matvar)
 {
     if ( NULL == matvar )
         return;
@@ -772,11 +778,12 @@ print_default(matvar_t *matvar)
                 Mat_Message("Fields[%d] {", nfields);
                 indent++;
                 {
-                    size_t j;
                     matvar_t **fields = (matvar_t **)matvar->data;
-                    if ( NULL != fields )
+                    if ( NULL != fields ) {
+                        size_t j;
                         for ( j = 0; j < nfields * nmemb; j++ )
                             print_default(fields[j]);
+                    }
                 }
                 indent--;
                 Mat_Message("}");
@@ -799,11 +806,12 @@ print_default(matvar_t *matvar)
             Mat_Message("{");
             indent++;
             {
-                size_t j;
                 matvar_t **cells = (matvar_t **)matvar->data;
-                if ( NULL != cells )
+                if ( NULL != cells ) {
+                    size_t j;
                     for ( j = 0; j < ncells; j++ )
                         print_default(cells[j]);
+                }
             }
             indent--;
             Mat_Message("}");
@@ -814,11 +822,19 @@ print_default(matvar_t *matvar)
     }
 }
 
+static void
+redirect_output(const char *output)
+{
+    if ( output != NULL )
+        if ( freopen(output, "w", stdout) == NULL )
+            fprintf(stderr, "Unable to open %s for writing. Using stdout instead.", output);
+}
+
 int
 main(int argc, char *argv[])
 {
     const char *prog_name = "matdump";
-    int i, c, err = EXIT_SUCCESS;
+    int c, err = EXIT_SUCCESS;
     mat_t *mat;
     matvar_t *matvar;
     int version[3];
@@ -858,13 +874,16 @@ main(int argc, char *argv[])
             case 'v':
                 Mat_SetVerbose(1, 0);
                 break;
+            case 'o':
+                redirect_output(optarg);
+                break;
             case 'H':
                 Mat_Help(helpstr);
                 /* Note: Mat_Help() calls exit() */
             case 'V':
                 printf(
                     "%s %s\nWritten by Christopher Hulbert\n\n"
-                    "Copyright(C) 2015-2023, The matio contributors\n"
+                    "Copyright(C) 2015-2024, The matio contributors\n"
                     "Copyright(C) 2006-2014, Christopher C. Hulbert\n",
                     prog_name, MATIO_VERSION_STR);
                 exit(EXIT_SUCCESS);
@@ -888,6 +907,7 @@ main(int argc, char *argv[])
     optind++;
 
     if ( optind < argc ) {
+        int i;
         /* variables specified on the command line */
         for ( i = optind; i < argc; i++ ) {
             char *next_tok_pos, next_tok = 0;
